==> haskell-heaps-0.3.6.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heaps
version:              0.3.6.1
visibility:           public
id:                   heaps-0.3.6.1-AmJ9jIsDwux7LWCRaEP67v
key:                  heaps-0.3.6.1-AmJ9jIsDwux7LWCRaEP67v
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  05da4e024716c2737fded214821868d7
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-8.10.1/site-local/heaps-0.3.6.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/heaps-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/heaps-0.3.6.1
hs-libraries:         HSheaps-0.3.6.1-AmJ9jIsDwux7LWCRaEP67v
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heaps-0.3.6.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heaps
version:              0.3.6.1
visibility:           public
id:                   heaps-0.3.6.1-FrjTwr5ICOu2l5ZH63kJaA
key:                  heaps-0.3.6.1-FrjTwr5ICOu2l5ZH63kJaA
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  6ac9b7dae6cf86cdff7dd260de0417e5
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-8.10.2/site-local/heaps-0.3.6.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/heaps-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/heaps-0.3.6.1
hs-libraries:         HSheaps-0.3.6.1-FrjTwr5ICOu2l5ZH63kJaA
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
